# GKBus

High-level KWP over K-Line/CANbus library powering the [GKFlasher](https://github.com/dante383/GKFlasher)

**WARNING: This library is in highly experimental stage, it was decoupled from GKFlasher's code to make development easier.**
You shouldn't use it yet. The code will be cleaned up and API documentation will be created after reaching MVP stage of GKFlasher
